@@ -14,6 +14,7 @@ from pymatgen.entries.computed_entries import ComputedEntry, ComputedStructureEn
 from emmet.core.electrode import InsertionElectrodeDoc
 from emmet.core.structure_group import StructureGroupDoc
 from emmet.core.utils import jsanitize
+from emmet.builders.settings import EmmetBuildSettings
 
 
 def s_hash(el):
@@ -73,6 +74,9 @@ def generic_groupby(list_in, comp=operator.eq):
     return list_out
 
 
+default_build_settings = EmmetBuildSettings()
+
+
 class StructureGroupBuilder(Builder):
     def __init__(
         self,
@@ -80,9 +84,9 @@ class StructureGroupBuilder(Builder):
         sgroups: MongoStore,
         working_ion: str,
         query: dict = None,
-        ltol: float = 0.2,
-        stol: float = 0.3,
-        angle_tol: float = 5.0,
+        ltol: float = default_build_settings.LTOL,
+        stol: float = default_build_settings.STOL,
+        angle_tol: float = default_build_settings.ANGLE_TOL,
         check_newer: bool = True,
         **kwargs,
     ):
@@ -342,6 +346,7 @@ class InsertionElectrodeBuilder(Builder):
             self.logger.debug(
                 f"Looking for {len(mat_ids)} material_id in the Thermo DB."
             )
+            self.thermo.connect()
             thermo_docs = list(
                 self.thermo.query(
                     {"$and": [{"material_id": {"$in": mat_ids}}]},
@@ -355,6 +360,7 @@ class InsertionElectrodeBuilder(Builder):
                     ],
                 )
             )
+
             self.logger.debug(f"Found for {len(thermo_docs)} Thermo Documents.")
             if len(thermo_docs) != len(mat_ids):
                 missing_ids = set(mat_ids) - set(
@@ -409,23 +415,17 @@ class InsertionElectrodeBuilder(Builder):
         entries = [
             tdoc_["entries"][tdoc_["energy_type"]] for tdoc_ in item["thermo_docs"]
         ]
+
         entries = list(map(ComputedStructureEntry.from_dict, entries))
 
         working_ion_entry = ComputedEntry.from_dict(
             item["working_ion_doc"]["entries"][item["working_ion_doc"]["energy_type"]]
         )
-        working_ion = working_ion_entry.composition.reduced_formula
 
         decomp_energies = {
             d_["material_id"]: d_["energy_above_hull"] for d_ in item["thermo_docs"]
         }
 
-        least_wion_ent = min(
-            entries, key=lambda x: x.composition.get_atomic_fraction(working_ion)
-        )
-        host_structure = least_wion_ent.structure.copy()
-        host_structure.remove_species([item["working_ion"]])
-
         for ient in entries:
             ient.data["volume"] = ient.structure.volume
             ient.data["decomposition_energy"] = decomp_energies[ient.entry_id]
@@ -434,7 +434,6 @@ class InsertionElectrodeBuilder(Builder):
             grouped_entries=entries,
             working_ion_entry=working_ion_entry,
             battery_id=item["group_id"],
-            host_structure=host_structure,
         )
         if ie is None:
             return None  # {"failed_reason": "unable to create InsertionElectrode document"}
